@@ -4,6 +4,8 @@
 import argparse
 import logging
 
+from git import Repo
+from notebuild.core.version import VersionManage
 from notebuild.shell import run_shell, run_shell_list
 
 logger = logging.getLogger("notebuild")
@@ -15,15 +17,21 @@ class PackageBuild:
     """
 
     def __init__(self, name=None):
-        res = run_shell("git rev-parse --show-toplevel", printf=False)
-        self.name = name or res.split('/')[-1]
+        self.repo_path = run_shell("git rev-parse --show-toplevel", printf=False)
+        self.name = name or self.repo_path.split('/')[-1]
+        self.repo = Repo(self.repo_path)
+
+        # self.git_url = run_shell("git remote -v", printf=False).split('\n')[0].split('\t')[1].split(' ')[0]
+        self.git_url = [url for url in self.repo.remote().urls][0]
+        self.version_manage = VersionManage(self.repo_path)
 
     def git_pull(self):
         """
         git pull
         """
         logger.info("{} pull".format(self.name))
-        run_shell("git pull")
+        # run_shell("git pull")
+        self.repo.remote().pull()
 
     def git_push(self):
         """
@@ -35,6 +43,9 @@ class PackageBuild:
             'git commit -a -m "add"',
             'git push'
         ])
+        self.repo.index.add(f"{self.repo_path}/*")
+        self.repo.index.commit(message='add')
+        self.repo.remote().pull()
 
     def git_install(self):
         """
@@ -54,10 +65,7 @@ class PackageBuild:
         """
         pip install
         """
-
-        a = run_shell("git remote -v", printf=False)
-        git_url = a.split('\n')[0].split('\t')[1].split(' ')[0]
-        run_shell('pip install -U -q git+{}'.format(git_url))
+        run_shell('pip install -U -q git+{}'.format(self.git_url))
         logger.info('pip install {} success'.format(self.name))
 
     def git_clear_build(self):
@@ -75,6 +83,8 @@ class PackageBuild:
         logger.info('{} build'.format(self.name))
         self.git_pull()
         self.git_clear_build()
+        self.version_manage.add()
+        self.version_manage.write()
         run_shell_list([
             'python3 setup.py build',  # 编译
             'python3 setup.py sdist',  # 生成 tar.gz
@@ -86,6 +96,7 @@ class PackageBuild:
         ])
         self.git_clear_build()
         self.git_push()
+        self.git_tags()
         self.pip_install()
 
     def git_clean_history(self):
@@ -114,6 +125,11 @@ class PackageBuild:
             'git gc --aggressive'
         ])
 
+    def git_tags(self):
+        self.repo.create_tag(self.version_manage.version)
+        self.repo.remote().push()
+        self.repo.remote().push(self.repo.tags)
+
 
 def command_line_parser():
     parser = argparse.ArgumentParser(description="Test")
